Symmetric to panel_lag(): the value of x for the same id at n
periods later in time, or NA if that exact key does not exist.
Symmetric to panel_lag(): the value of x for the same id at n
periods later in time, or NA if that exact key does not exist.